@@ -9,8 +9,11 @@ working_path = env.get_env_value("PWD")
 ROOT_DIR = Path(working_path)
 FUNCTIONS_PATH = ROOT_DIR / "functions"
 IGNORE_MODELS_PATH = ROOT_DIR / ".ignore_models"
-SCHEDULEMANAGER_EXTERNAL_ID = "cognitedata/air-ds-infrastructure/schedulemanager:latest"
-AIR_FUNCTIONS_SCHEDULEMANAGER_EXTERNAL_ID = "cognitedata/air-functions/schedulemanager:latest"
+SCHEDULE_MANAGER_EXTERNAL_IDS = [
+    "cognitedata/air-ds-infrastructure/schedulemanager:latest",
+    "cognitedata/air-functions/schedulemanager:latest",
+    "cognitedata/air-ds-infrastructure/schedulemanager2:latest",
+]
 
 # Paths within a functions folder
 FUNCTION_REL_PATH = Path("function")
